==> af-common-socket-2.14.10-sources.jar: com/af/v4/system/common/socket/core/channel/impl/ModbusTCPChannelHandler.java <==
package com.af.v4.system.common.socket.core.channel.impl;

import com.af.v4.system.common.core.proxy.logic.ILogicServiceProxy;
import com.af.v4.system.common.core.utils.SpringUtils;
import com.af.v4.system.common.plugins.core.ConvertTools;
import com.af.v4.system.common.socket.config.ClientEvent;
import com.af.v4.system.common.socket.core.channel.AbstractChannelHandler;
import com.af.v4.system.common.socket.core.server.modbus.message.MBAPHeader;
import com.af.v4.system.common.socket.core.server.modbus.message.PduPayload;
import com.af.v4.system.common.socket.core.server.modbus.util.MBAPHeaderDecoder;
import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Arrays;

import static com.af.v4.system.common.socket.core.client.modbus.ModBusClient.MOD_BUS_EVENT_MAP;


/**
 * Modbus TCP
 */
public class ModbusTCPChannelHandler extends AbstractChannelHandler<ByteBuf> {

    public static final int HEADER_LENGTH = 8;// // transactionId(2) + protocolId(2) + length(2) + unitId(1)+ functionCode(1)

    private final Logger LOGGER = LoggerFactory.getLogger(ModbusTCPChannelHandler.class);

    @Override
    protected void read(ChannelHandlerContext ctx, ByteBuf msg) {
        int totalLen = msg.readableBytes();
        if (totalLen < HEADER_LENGTH) {
            LOGGER.info("not modbus TCP protocol:");
            return;
        }
        //header
        MBAPHeader mbapHeader = MBAPHeaderDecoder.decode(msg);
        //pdu
        PduPayload pduPayload = new PduPayload();
        short functionCode = msg.readUnsignedByte();
        pduPayload.setFunctionCode(functionCode);
        int dataLength = 0;
        if (totalLen > HEADER_LENGTH) {
            dataLength = totalLen - HEADER_LENGTH;
        }
        pduPayload.setDataLength((short) dataLength);
        byte[] data = new byte[dataLength];
        msg.readBytes(data);
        try {
            pduPayload.setData(data);
        } catch (IllegalArgumentException e) {
            LOGGER.error(e.getMessage());
            // 处理异常，直接返回或者记录日志，后续代码不再执行
            return;
        }
        ClientEvent event = MOD_BUS_EVENT_MAP.get(mbapHeader.getTransactionId());
        String _data = switch (event.getDecodeType()) {
            case FLOAT -> Float.toString(ConvertTools.bytesToFloat(pduPayload.getRealData()));
            case BYTE_TO_SCALED_INT -> Integer.toString(ConvertTools.bytesToInt(pduPayload.getRealData(), 0));
            default -> Arrays.toString(pduPayload.getRealData());
        };
        JSONObject logicParam = new JSONObject();
        logicParam.put("event", event);
        logicParam.put(event.getAlias(), _data);
        SpringUtils.getBean(ILogicServiceProxy.class).run(event.getLogicName(), logicParam);
    }
}

==> af-common-socket-2.14.18-sources.jar: com/af/v4/system/common/socket/core/channel/impl/ModbusTCPChannelHandler.java <==
package com.af.v4.system.common.socket.core.channel.impl;

import com.af.v4.system.common.core.proxy.logic.ILogicServiceProxy;
import com.af.v4.system.common.core.utils.SpringUtils;
import com.af.v4.system.common.plugins.core.ConvertTools;
import com.af.v4.system.common.socket.config.ClientEvent;
import com.af.v4.system.common.socket.core.channel.AbstractChannelHandler;
import com.af.v4.system.common.socket.core.server.modbus.message.MBAPHeader;
import com.af.v4.system.common.socket.core.server.modbus.message.PduPayload;
import com.af.v4.system.common.socket.core.server.modbus.util.MBAPHeaderDecoder;
import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Arrays;

import static com.af.v4.system.common.socket.core.client.modbus.ModBusClient.MOD_BUS_EVENT_MAP;


/**
 * Modbus TCP
 */
public class ModbusTCPChannelHandler extends AbstractChannelHandler<ByteBuf> {

    public static final int HEADER_LENGTH = 8;// // transactionId(2) + protocolId(2) + length(2) + unitId(1)+ functionCode(1)

    private final Logger LOGGER = LoggerFactory.getLogger(ModbusTCPChannelHandler.class);

    @Override
    protected void read(ChannelHandlerContext ctx, ByteBuf msg) {
        int totalLen = msg.readableBytes();
        if (totalLen < HEADER_LENGTH) {
            LOGGER.info("not modbus TCP protocol:");
            return;
        }
        //header
        MBAPHeader mbapHeader = MBAPHeaderDecoder.decode(msg);
        //pdu
        PduPayload pduPayload = new PduPayload();
        short functionCode = msg.readUnsignedByte();
        pduPayload.setFunctionCode(functionCode);
        int dataLength = 0;
        if (totalLen > HEADER_LENGTH) {
            dataLength = totalLen - HEADER_LENGTH;
        }
        pduPayload.setDataLength((short) dataLength);
        byte[] data = new byte[dataLength];
        msg.readBytes(data);
        try {
            pduPayload.setData(data);
        } catch (IllegalArgumentException e) {
            LOGGER.error(e.getMessage());
            // 处理异常，直接返回或者记录日志，后续代码不再执行
            return;
        }
        ClientEvent event = MOD_BUS_EVENT_MAP.getIfPresent(mbapHeader.getTransactionId());
        assert event != null;
        String _data = switch (event.getDecodeType()) {
            case FLOAT -> Float.toString(ConvertTools.bytesToFloat(pduPayload.getRealData()));
            case BYTE_TO_SCALED_INT -> Integer.toString(ConvertTools.bytesToInt(pduPayload.getRealData(), 0));
            default -> Arrays.toString(pduPayload.getRealData());
        };
        JSONObject logicParam = new JSONObject();
        logicParam.put("event", event);
        logicParam.put(event.getAlias(), _data);
        SpringUtils.getBean(ILogicServiceProxy.class).run(event.getLogicName(), logicParam);
    }
}
